@@ -75,20 +75,22 @@ add_lpsymphony_solver <- function(x, gap = 0.1, time_limit = -1,
   # throw warning about bug in lpsymphony
   if (utils::packageVersion("lpsymphony") <= as.package_version("1.4.1"))
     warning(paste0("The solution may be incorrect due to a bug in ",
-                   "lpsymphony. Please verify that it is correct, ",
-                   "or use a different solver to generate solutions."))
+                   "lpsymphony, please verify that it is correct, ",
+                   "or use a different solver to generate solutions"))
   # add solver
   x$add_solver(pproto(
     "LpsymphonySolver",
     Solver,
     name = "Lpsymphony",
+    data = list(),
     parameters = parameters(
       numeric_parameter("gap", gap, lower_limit = 0),
       integer_parameter("time_limit", time_limit, lower_limit = -1,
                         upper_limit = .Machine$integer.max),
       binary_parameter("first_feasible", first_feasible),
       binary_parameter("verbose", verbose)),
-    solve = function(self, x) {
+    calculate = function(self, x, ...) {
+      # create model
       model <- list(
         obj = x$obj(),
         mat = as.matrix(x$A()),
@@ -107,17 +109,49 @@ add_lpsymphony_solver <- function(x, gap = 0.1, time_limit = -1,
       model$dir <- replace(model$dir, model$dir == "=", "==")
       model$types <- replace(model$types, model$types == "S", "C")
       p$first_feasible <- as.logical(p$first_feasible)
+      # store input data and parameters
+      self$set_data("model", model)
+      self$set_data("parameters", p)
+      # return success
+      invisible(TRUE)
+    },
+    run = function(self) {
+      # access input data and parameters
+      model <- self$get_data("model")
+      p <- self$get_data("parameters")
+      # solve problem
       start_time <- Sys.time()
-      s <- do.call(lpsymphony::lpsymphony_solve_LP, append(model, p))
+      x <- do.call(lpsymphony::lpsymphony_solve_LP, append(model, p))
       end_time <- Sys.time()
-      if (is.null(s$solution) ||
-          names(s$status) %in% c("TM_NO_SOLUTION", "PREP_NO_SOLUTION"))
+      if (is.null(x$solution) ||
+          names(x$status) %in% c("TM_NO_SOLUTION", "PREP_NO_SOLUTION"))
         return(NULL)
-      if (any(s$solution > 1 | s$solution < 0))
-        stop("infeasible solution returned, try relaxing solver parameters")
-      return(list(x = s$solution, objective = s$objval,
-                  status = as.character(s$status),
+      if (any(x$solution > 1)) {
+        if (max(x$solution) < 1.01) {
+          x$solution[x$solution > 1] <- 1
+        } else {
+          stop("infeasible solution returned, try relaxing solver parameters")
+        }
+      }
+      if (any(x$solution < 0)) {
+        if (min(x$solution) > -0.01) {
+          x$solution[x$solution < 0] <- 0
+        } else {
+          stop("infeasible solution returned, try relaxing solver parameters")
+        }
+      }
+      # return output
+      return(list(x = x$solution, objective = x$objval,
+                  status = as.character(x$status),
                   runtime = as.double(end_time - start_time,
                                       format = "seconds")))
+    },
+    set_variable_ub = function(self, index, value) {
+      self$data$model$bounds$upper$val[index] <- value
+      invisible(TRUE)
+    },
+    set_variable_lb = function(self, index, value) {
+      self$data$model$bounds$lower$val[index] <- value
+      invisible(TRUE)
     }))
 }
