@@ -90,13 +90,15 @@ add_rsymphony_solver <- function(x, gap = 0.1, time_limit = -1,
     "RsymphonySolver",
     Solver,
     name = "Rsymphony",
+    data = list(),
     parameters = parameters(
       numeric_parameter("gap", gap, lower_limit = 0),
       integer_parameter("time_limit", time_limit, lower_limit = -1,
                         upper_limit = .Machine$integer.max),
       binary_parameter("first_feasible", first_feasible),
       binary_parameter("verbose", verbose)),
-    solve = function(self, x) {
+    calculate = function(self, x, ...) {
+      # create model
       model <- list(
         obj = x$obj(),
         mat = x$A(),
@@ -115,14 +117,46 @@ add_rsymphony_solver <- function(x, gap = 0.1, time_limit = -1,
       model$types <- replace(model$types, model$types == "S", "C")
       names(p)[which(names(p) == "gap")] <- "gap_limit"
       p$first_feasible <- as.logical(p$first_feasible)
+      # store input data and parameters
+      self$set_data("model", model)
+      self$set_data("parameters", p)
+      # return success
+      invisible(TRUE)
+    },
+    set_variable_ub = function(self, index, value) {
+      self$data$model$bounds$upper$val[index] <- value
+      invisible(TRUE)
+    },
+    set_variable_lb = function(self, index, value) {
+      self$data$model$bounds$lower$val[index] <- value
+      invisible(TRUE)
+    },
+    run = function(self) {
+      # access input data and parameters
+      model <- self$get_data("model")
+      p <- self$get_data("parameters")
+      # solve problem
       start_time <- Sys.time()
       x <- do.call(Rsymphony::Rsymphony_solve_LP, append(model, p))
       end_time <- Sys.time()
       if (is.null(x$solution) ||
           names(x$status) %in% c("TM_NO_SOLUTION", "PREP_NO_SOLUTION"))
         return(NULL)
-      if (any(x$solution > 1 | x$solution < 0))
-        stop("infeasible solution returned, try relaxing solver parameters")
+        if (any(x$solution > 1)) {
+          if (max(x$solution) < 1.01) {
+            x$solution[x$solution > 1] <- 1
+          } else {
+            stop("infeasible solution returned, try relaxing solver parameters")
+          }
+        }
+        if (any(x$solution < 0)) {
+          if (min(x$solution) > -0.01) {
+            x$solution[x$solution < 0] <- 0
+          } else {
+            stop("infeasible solution returned, try relaxing solver parameters")
+          }
+        }
+      # return output
       return(list(x = x$solution, objective = x$objval,
                   status = as.character(x$status),
                   runtime = as.double(end_time - start_time,
